#
# spec file for package sil-charis-fonts
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sil-charis-fonts
Version:        6.200
Release:        1.1
Summary:        Smart Unicode Font for Latin and Cyrillic Scripts
License:        OFL-1.1
Group:          System/X11/Fonts
URL:            https://software.sil.org/charis/
Source0:        https://software.sil.org/downloads/r/charis/CharisSIL-%{version}.zip
BuildRequires:  fontpackages-devel
BuildRequires:  unzip
%reconfigure_fonts_prereq
Provides:       locale(vi;ru;bg)
BuildArch:      noarch

%description
Charis is similar to Bitstream Charter, one of the first fonts designed
specifically for laser printers. It is highly readable and holds up
well in less-than-ideal reproduction environments. It also has a full
set of styles - regular, italic, bold, bold italic - and so is more
useful in general publishing than Doulos SIL. Charis is a serif,
proportionally-spaced font optimized for readability in long printed
documents.

The goal for this product was to provide a single Unicode-based font
family that would contain a comprehensive inventory of glyphs needed
for almost any Roman- or Cyrillic-based writing system, whether used
for phonetic or orthographic needs. In addition, there is provision for
other characters and symbols useful to linguists. This font makes use
of state-of-the-art font technologies to support complex typographic
issues, such as the need to position arbitrary combinations of base
glyphs and diacritics optimally.

%prep
%setup -q -n CharisSIL-%{version}
chmod 644 *.txt
# Remove DOS line endings:
perl -i -pe 's{\r}{}g' *.txt

%build

%install
install -d %{buildroot}%{_ttfontsdir}
install -c -m 644 *.ttf %{buildroot}%{_ttfontsdir}

%reconfigure_fonts_scriptlets

%files
%defattr(-, root,root)
%license OFL.txt
%doc FONTLOG.txt OFL-FAQ.txt README.txt
%{_ttfontsdir}

%changelog
* Thu Feb  2 2023 Cor Blom <cornelis@solcon.nl>
- Update to 6.200:
  * This release is focused on adding features and 240+ glyphs,
    including support for over 180 additional characters mostly
    from Unicode 14 and 15. It does not include significant changes
    to line spacing, glyph widths, or kerning that might cause
    document reflow or layout changes—except for minor improvements
    to the size and weight of superscript, subscript, and modifier
    letters
  * Most important changes: support for subscript and superscript
    numerals and automatic fractions
* Tue Feb 22 2022 Cor Blom <cornelis@solcon.nl>
- Update to 6.101:
  * Maintenance release
* Sun Aug  8 2021 Cor Blom <cornelis@solcon.nl>
- Use different method to remove dos line ending and remove
  dos2unix from BuildRequires
* Sat Aug  7 2021 Cor Blom <cornelis@solcon.nl>
- Update to version 6.001:
  * Major feature release with many changes. This release has
    removed the graphite support.
- Clean up spec and remove old bits
* Wed Apr 14 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Fixed URL in spec
* Tue Mar 24 2015 p.drouand@gmail.com
- Update to version 5.000
  * Added Stylistic Sets to the font for OpenType support of
    previously Graphite-only features
  * Added Character Variants to the font for OpenType support of
    previously Graphite-only features
  * Added Serbian feature when Serbian language is turned on
  * Added hook D variant feature (for U+018A/U+0257)
  * Removed "Show deprecated PUA" feature
  * Removed “Romanian-style diacritics” feature (because glyphs are
    now encoded)
  * Removed “Diacritic selection” feature
  * Added U+039E, U+03BC, U+03C6 and U+03C9 in the Greek and Coptic block
  * Added U+0528..U+052F in the Cyrillic Supplement block
  * Added U+2041 in the General Punctuation block
  * Added U+2095..U+209C in the Superscripts and Subscripts block
  * Added U+20B6..U+20BD in the Currency Symbols block
  * Added U+210C, U+2113, U+2117, U+212D, U+2135, U+214F in the
    Letterlike Symbols block
  * Added U+2150..U+2152 and U+2189 in the Number Forms block
  * Added U+2226, U+2234..U+2235, U+2262, U+2282..U+2287 in the
    Mathematical Operators block
  * Added U+2640, U+2642, U+266D, U+266F in the Miscellaneous Symbols block
  * Added U+27E8..U+27E9 in the Miscellaneous Mathematical Symbols-A block
  * Added U+2C7E..U+2C7F in the Latin Extended-C block
  * Added U+2C88 in the Coptic block
  * Added U+2E00..U+2E0D, U+2E3A..U+2E3B in the Supplemental Punctuation block
  * Added U+A736..U+A73F, U+A742..U+A74D, U+A750..U+A787, U+A790..U+A7AD,
    U+A7B0..U+A7B1, U+A7F7..U+A7FA in the Latin Extended-D block. These were
    also added to relevant features.
  * Added U+A92E in the Kayah Li block (to support the Kayah Li language
    when using the Roman script)
  * Added U+AB64..U+AB65 in the Latin Extended-E block
  * Added U+1D40C, U+1D504..U+1D505, U+1D50A, U+1D50E..U+1D50F, U+1D514,
    U+1D516..U+1D517, U+1D519 in the Mathematical Alphanumeric Symbols block
  * Added PUA characters U+F26C (curl J) and U+F26D (left-hook b)
  * Characters in our PUA that were added to Unicode have had their
    codepoints updated: F1AD>A7F9, F266>A78E, F26B>A78D, F32C>0526,
    F32D>0527, F17B>1DFD, F209>2C70
  * These PUA characters were deprecated (now white on black glyphs):
    U+F17B, U+F1AD, U+F209, U+F247, U+F248, U+F266, U+F26B, U+F32C, U+F32D
  * Deleted U+0149 as it is officially deprecated in Unicode
  * Added support for shorter macrons under narrow letters (i,l,r,t).
  (This only works for Graphite or using precomposed characters in OpenType.)
  * Made it possible for saltillo characters (U+A78B and U+A78C) to "carry" diacritics
  * Improved design of U+A722..U+A725 and U+A78D
  * Refactored all cedilla positioning
  * Removal of unneeded duplicate glyphs (because of improvements in smart font code)
  * Bug fix in Graphite code to allow for simultaneous selection of
    Vietnamese alternates and Small Caps
  * Bug fix in Graphite code to allow for simultaneous selection of
    Ogonek alternates and Small Caps
  * "Hide tone contour staves" feature now works with single tonebar
  * Allowed combining marks to render properly with U+02D0
  * Changed postscript names for U+0218 and U+0219
  * Changed postscript names for U+2203, U+232A and U+2329
  * Improved hinting
  * Significant size, position and metric changes made to Subscript and
    Superscript parentheses, plus, minus, equals.
  * Size of guillemots (U+00AB U+00BB U+2039 U+203A) modified to match
    the font. Metrics were not changed.
  * Arrowhead design of U+21A8 modified to match the other arrows
  * Placement of Ogonek revisited
  * Slight modification to positioning of U+0361 and U+035C in Italic and Bold Italic
  * Changed the strongly curved hooks on Cyrillic U+04C3..U+04C4,
    U+04C7..U+04C8, U+04FC..U+04FD, U+0512..U+0513 to be more consistent
    with other hooks
  * Modified Cyrillic italic versions of U+04AF, U+04B1, U+04B5, U+04BC
    U+04BE, U+04D8
  * Modified design of U+A78D to be more curved and less squared
  * U+1DBF now follows weight and italic change
* Tue May  6 2014 toms@opensuse.org
- Spec file:
  Some applications (like XEP) needs the "old" filenames.
  As such, create links with old naming without "-"
* Wed Apr  9 2014 cornelis@solcon.nl
- Update to 4.114: better, faster rendering in Graphite
- Update to 4.112: change Graphite feature identifiers from integers to 4-character alphanumeric tags, this is needed for Graphite support in newer firefox and LibreOffice
- Remove Changes.txt, which is obsolete now (and origin of this file is unclear)
* Wed Jul  4 2012 pgajdos@suse.cz
- amend spec file to reflect new font packaging scheme
  (see openFATE#313536);
* Thu May 17 2012 pgajdos@suse.com
- call spec-cleaner
* Wed Dec 21 2011 toms@suse.de
- Renamed sil-charis -> sil-charis-fonts according to
  openSUSE packaging guidelines and FATE#313035
  Adjusted Obsoletes and Provides accordingly
* Thu Apr  8 2010 tiwai@suse.de
- remove unnecessary buildrequires for too old distros
* Sat Mar 27 2010 toms@suse.de
- Updated to version 4.106
- Added new Changes.txt file
- Added dos2unix BuildRequires
* Thu Mar 29 2007 rguenther@suse.de
- add unzip BuildRequires
* Fri Oct 20 2006 mfabian@suse.de
- new package: sil-charis, 4.0.02
